import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AppRoleAssignmentConfig extends cdktf.TerraformMetaArguments {
    /**
     * The ID of the app role to be assigned.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/app_role_assignment.html#app_role_id AppRoleAssignment#app_role_id}
     *
     * @stability stable
     */
    readonly appRoleId: string;
    /**
     * The object ID of the user, group or service principal to be assigned this app role.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/app_role_assignment.html#principal_object_id AppRoleAssignment#principal_object_id}
     *
     * @stability stable
     */
    readonly principalObjectId: string;
    /**
     * The object ID of the service principal representing the resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/app_role_assignment.html#resource_object_id AppRoleAssignment#resource_object_id}
     *
     * @stability stable
     */
    readonly resourceObjectId: string;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/app_role_assignment.html#timeouts AppRoleAssignment#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: AppRoleAssignmentTimeouts;
}
/**
 * @stability stable
 */
export interface AppRoleAssignmentTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/app_role_assignment.html#create AppRoleAssignment#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/app_role_assignment.html#delete AppRoleAssignment#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/app_role_assignment.html#read AppRoleAssignment#read}.
     *
     * @stability stable
     */
    readonly read?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azuread/r/app_role_assignment.html azuread_app_role_assignment}.
 *
 * @stability stable
 */
export declare class AppRoleAssignment extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azuread/r/app_role_assignment.html azuread_app_role_assignment} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AppRoleAssignmentConfig);
    private _appRoleId;
    /**
     * @stability stable
     */
    get appRoleId(): string;
    /**
     * @stability stable
     */
    set appRoleId(value: string);
    /**
     * @stability stable
     */
    get appRoleIdInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get principalDisplayName(): string;
    private _principalObjectId;
    /**
     * @stability stable
     */
    get principalObjectId(): string;
    /**
     * @stability stable
     */
    set principalObjectId(value: string);
    /**
     * @stability stable
     */
    get principalObjectIdInput(): string;
    /**
     * @stability stable
     */
    get principalType(): string;
    /**
     * @stability stable
     */
    get resourceDisplayName(): string;
    private _resourceObjectId;
    /**
     * @stability stable
     */
    get resourceObjectId(): string;
    /**
     * @stability stable
     */
    set resourceObjectId(value: string);
    /**
     * @stability stable
     */
    get resourceObjectIdInput(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): AppRoleAssignmentTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: AppRoleAssignmentTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): AppRoleAssignmentTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
