import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ApplicationPreAuthorizedConfig extends cdktf.TerraformMetaArguments {
    /**
     * The object ID of the application to which this pre-authorized application should be added.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/application_pre_authorized.html#application_object_id ApplicationPreAuthorized#application_object_id}
     *
     * @stability stable
     */
    readonly applicationObjectId: string;
    /**
     * The application ID of the pre-authorized application.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/application_pre_authorized.html#authorized_app_id ApplicationPreAuthorized#authorized_app_id}
     *
     * @stability stable
     */
    readonly authorizedAppId: string;
    /**
     * The IDs of the permission scopes required by the pre-authorized application.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/application_pre_authorized.html#permission_ids ApplicationPreAuthorized#permission_ids}
     *
     * @stability stable
     */
    readonly permissionIds: string[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/application_pre_authorized.html#timeouts ApplicationPreAuthorized#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ApplicationPreAuthorizedTimeouts;
}
/**
 * @stability stable
 */
export interface ApplicationPreAuthorizedTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/application_pre_authorized.html#create ApplicationPreAuthorized#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/application_pre_authorized.html#delete ApplicationPreAuthorized#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/application_pre_authorized.html#read ApplicationPreAuthorized#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/application_pre_authorized.html#update ApplicationPreAuthorized#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azuread/r/application_pre_authorized.html azuread_application_pre_authorized}.
 *
 * @stability stable
 */
export declare class ApplicationPreAuthorized extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azuread/r/application_pre_authorized.html azuread_application_pre_authorized} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ApplicationPreAuthorizedConfig);
    private _applicationObjectId;
    /**
     * @stability stable
     */
    get applicationObjectId(): string;
    /**
     * @stability stable
     */
    set applicationObjectId(value: string);
    /**
     * @stability stable
     */
    get applicationObjectIdInput(): string;
    private _authorizedAppId;
    /**
     * @stability stable
     */
    get authorizedAppId(): string;
    /**
     * @stability stable
     */
    set authorizedAppId(value: string);
    /**
     * @stability stable
     */
    get authorizedAppIdInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _permissionIds;
    /**
     * @stability stable
     */
    get permissionIds(): string[];
    /**
     * @stability stable
     */
    set permissionIds(value: string[]);
    /**
     * @stability stable
     */
    get permissionIdsInput(): string[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ApplicationPreAuthorizedTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ApplicationPreAuthorizedTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ApplicationPreAuthorizedTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
