import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataAzureadGroupsConfig extends cdktf.TerraformMetaArguments {
    /**
     * The display names of the groups.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/groups.html#display_names DataAzureadGroups#display_names}
     *
     * @stability stable
     */
    readonly displayNames?: string[];
    /**
     * The object IDs of the groups.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/groups.html#object_ids DataAzureadGroups#object_ids}
     *
     * @stability stable
     */
    readonly objectIds?: string[];
    /**
     * Retrieve all groups with no filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/groups.html#return_all DataAzureadGroups#return_all}
     *
     * @stability stable
     */
    readonly returnAll?: boolean | cdktf.IResolvable;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/groups.html#timeouts DataAzureadGroups#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DataAzureadGroupsTimeouts;
}
/**
 * @stability stable
 */
export interface DataAzureadGroupsTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/groups.html#read DataAzureadGroups#read}.
     *
     * @stability stable
     */
    readonly read?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azuread/d/groups.html azuread_groups}.
 *
 * @stability stable
 */
export declare class DataAzureadGroups extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azuread/d/groups.html azuread_groups} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: DataAzureadGroupsConfig);
    private _displayNames?;
    /**
     * @stability stable
     */
    get displayNames(): string[];
    /**
     * @stability stable
     */
    set displayNames(value: string[]);
    /**
     * @stability stable
     */
    resetDisplayNames(): void;
    /**
     * @stability stable
     */
    get displayNamesInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _objectIds?;
    /**
     * @stability stable
     */
    get objectIds(): string[];
    /**
     * @stability stable
     */
    set objectIds(value: string[]);
    /**
     * @stability stable
     */
    resetObjectIds(): void;
    /**
     * @stability stable
     */
    get objectIdsInput(): string[] | undefined;
    private _returnAll?;
    /**
     * @stability stable
     */
    get returnAll(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set returnAll(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReturnAll(): void;
    /**
     * @stability stable
     */
    get returnAllInput(): boolean | cdktf.IResolvable | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DataAzureadGroupsTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DataAzureadGroupsTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DataAzureadGroupsTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
