import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DirectoryRoleMemberConfig extends cdktf.TerraformMetaArguments {
    /**
     * The object ID of the member.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/directory_role_member.html#member_object_id DirectoryRoleMember#member_object_id}
     *
     * @stability stable
     */
    readonly memberObjectId?: string;
    /**
     * The object ID of the directory role.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/directory_role_member.html#role_object_id DirectoryRoleMember#role_object_id}
     *
     * @stability stable
     */
    readonly roleObjectId?: string;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/directory_role_member.html#timeouts DirectoryRoleMember#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DirectoryRoleMemberTimeouts;
}
/**
 * @stability stable
 */
export interface DirectoryRoleMemberTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/directory_role_member.html#create DirectoryRoleMember#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/directory_role_member.html#delete DirectoryRoleMember#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/directory_role_member.html#read DirectoryRoleMember#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/directory_role_member.html#update DirectoryRoleMember#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azuread/r/directory_role_member.html azuread_directory_role_member}.
 *
 * @stability stable
 */
export declare class DirectoryRoleMember extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azuread/r/directory_role_member.html azuread_directory_role_member} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: DirectoryRoleMemberConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _memberObjectId?;
    /**
     * @stability stable
     */
    get memberObjectId(): string;
    /**
     * @stability stable
     */
    set memberObjectId(value: string);
    /**
     * @stability stable
     */
    resetMemberObjectId(): void;
    /**
     * @stability stable
     */
    get memberObjectIdInput(): string | undefined;
    private _roleObjectId?;
    /**
     * @stability stable
     */
    get roleObjectId(): string;
    /**
     * @stability stable
     */
    set roleObjectId(value: string);
    /**
     * @stability stable
     */
    resetRoleObjectId(): void;
    /**
     * @stability stable
     */
    get roleObjectIdInput(): string | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DirectoryRoleMemberTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DirectoryRoleMemberTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DirectoryRoleMemberTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
